Grammar

Struct Grammar 

pub struct Grammar {
    pub name: String,
    pub scope_name: String,
    pub scopes: Vec<String>,
    pub kind: GrammarKind,
    /* private fields */
}
Immutable compiled grammar data.

Fields

name: String

Human-readable grammar name.

scope_name: String

Root scope name.

scopes: Vec<String>

Interned scope names used by this grammar.

kind: GrammarKind

Tokenization strategy used by this grammar.

Implementations

Source

impl Grammar

pub fn compile(raw: &RawGrammar) -> Result<Self, Error>

Compiles a raw grammar.

pub fn plain_text() -> Self

Builds a grammar with no patterns for plain text fallback.

pub fn json() -> Self

Builds the dedicated fast JSON grammar.

This does not use the recursive TextMate tokenizer. It emits the same kind of ScopeSpan values as compiled grammars while scanning each line directly.

pub fn matches_name(&self, name: &str) -> bool

Returns true when this grammar matches a syntax name or alias.

pub fn matches_path(&self, path: &Path) -> bool

Returns true when this grammar matches a file path.

pub fn matches_first_line(&self, line: &str) -> bool

Returns true when this grammar matches the first source line.

pub fn tokenize_line(&self, state: &mut LineState, line: &str) -> Vec<ScopeSpan>

Tokenizes one line, mutating the caller-owned line state.

pub fn tokenize_line_into( &self, state: &mut LineState, line: &str, spans: &mut Vec<ScopeSpan>, )

Tokenizes one line into a caller-owned buffer.