GrammarQuery

Struct GrammarQuery 

pub struct GrammarQuery<'a> {
    pub syntax: Option<&'a str>,
    pub path: Option<&'a Path>,
    pub first_line: Option<&'a str>,
}
Inputs used to select a grammar from a registry.

Fields

syntax: Option<&'a str>

Explicit syntax name, root scope, extension, or file-type alias.

path: Option<&'a Path>

Source path used for file-name and extension inference.

first_line: Option<&'a str>

First source line used for shebang and modeline inference.