pub struct StyleSpan {
pub start: usize,
pub end: usize,
pub scope: Option<ScopeId>,
pub style: Style,
}Expand description
Fully styled span produced by applying a Theme to scope spans.
Fields
start: usizeStart byte in the line.
end: usizeEnd byte in the line.
scope: Option<ScopeId>The most specific scope covering this styled span, if any.
style: StyleResolved style.